@@ -30,15 +30,13 @@
 typedef enum log_message_name
 {
   LOG_MESSAGE_ERROR_DECOMPRESS,
-  LOG_MESSAGE_ERROR_DOWNLOAD,
-  LOG_MESSAGE_ERROR_INSTALL_LIST,
-  LOG_MESSAGE_ERROR_INSTALL_ROOT,
-  LOG_MESSAGE_ERROR_INTERNAL,
-  LOG_MESSAGE_ERROR_PARSE,
-  LOG_MESSAGE_INFO_DOWNLOAD_RETRIEVE,
+  LOG_MESSAGE_ERROR_DOWNLOAD_PARSE,
+  LOG_MESSAGE_ERROR_DOWNLOAD_RETRIEVE,
+  LOG_MESSAGE_ERROR_DOWNLOAD_VALIDATE,
+  LOG_MESSAGE_WARNING_DOWNLOAD_VALIDATE,
   LOG_MESSAGE_INFO_DOWNLOAD_PARSE,
+  LOG_MESSAGE_INFO_DOWNLOAD_RETRIEVE,
   LOG_MESSAGE_INFO_DOWNLOAD_VALIDATE,
-  LOG_MESSAGE_INFO_INSTALL_HELPER_EXECUTE,
   LOG_MESSAGE_INFO_INSTALL_HELPER_INSTALL,
   LOG_MESSAGE_INFO_INSTALL_HELPER_REMOVE,
   LOG_MESSAGE_INFO_INSTALL_PACKAGE_CONFIGURE,
