@@ -18,8 +18,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  * $LastChangedBy: bastian $
- * $LastChangedDate: 2006-08-24 19:40:20 +0000 (Do, 24 Aug 2006) $
- * $LastChangedRevision: 1243 $
+ * $LastChangedDate: 2009-08-31 13:07:50 +0200 (Mo, 31 Aug 2009) $
+ * $LastChangedRevision: 1706 $
  */
 
 #include <config.h>
@@ -27,7 +27,7 @@
 #include "execute.h"
 #include "frontend.h"
 #include "install.h"
-#include "packages.h"
+#include "package.h"
 #include "suite.h"
 #include "suite_action.h"
 #include "suite_config.h"
@@ -39,11 +39,6 @@ static di_package_priority cur_list_priority;
 
 typedef int suite_install_action (suite_config_action *action, int data, di_packages *packages, di_packages_allocator *allocator, di_slist *install);
 
-static int action_execute (suite_config_action *action, int data __attribute__ ((unused)), di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
-{
-  return install_helper_execute (action->what);
-}
-
 static di_package_priority action_check_priority (const char *text)
 {
   if (text)
@@ -75,8 +70,8 @@ static int action_install (suite_config_action *action, int _data, di_packages *
 {
   enum action_install data = _data;
 
-  int force = action->flags && SUITE_CONFIG_ACTION_FLAG_FORCE;
-  int only = action->flags && SUITE_CONFIG_ACTION_FLAG_ONLY;
+  int force = action->flags & SUITE_CONFIG_ACTION_FLAG_FORCE;
+  int only = action->flags & SUITE_CONFIG_ACTION_FLAG_ONLY;
   di_package_priority priority;
   di_slist *list;
   int cleanup = 0;
@@ -128,62 +123,19 @@ static int action_install (suite_config_action *action, int _data, di_packages *
   return 0;
 }
 
-enum action_helper
+static int action_helper_install (suite_config_action *action, int data __attribute__ ((unused)), di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
 {
-  ACTION_HELPER_INSTALL,
-  ACTION_HELPER_REMOVE,
-};
-
-static int action_helper (suite_config_action *action __attribute__ ((unused)), int data, di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
-{
-  switch (data)
-  {
-    case ACTION_HELPER_INSTALL:
-      return install_helper_install (action->what);
-    case ACTION_HELPER_REMOVE:
-      return install_helper_remove (action->what);
-  };
-  return 0;
+  return install_helper_install (action->what);
 }
 
-enum action_mount
+static int action_helper_remove (suite_config_action *action, int data __attribute__ ((unused)), di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
 {
-  ACTION_MOUNT_DEV,
-  ACTION_MOUNT_PROC,
-};
-
-static int action_mount (suite_config_action *action __attribute__ ((unused)), int data __attribute__ ((unused)), di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
-{
-  switch (data)
-  {
-    case ACTION_MOUNT_DEV:
-      if (install_mount_dev ())
-        log_text (DI_LOG_LEVEL_ERROR, "can't mount dev");
-      break;
-    case ACTION_MOUNT_PROC:
-      if (install_mount_proc ())
-        log_text (DI_LOG_LEVEL_ERROR, "can't mount proc");
-      break;
-  }
-  return 0;
+  return install_helper_remove (action->what);
 }
 
-enum action_prepare
+static int action_mount (suite_config_action *action, int data __attribute__ ((unused)), di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
 {
-  ACTION_PREPARE_APT_PREPARE,
-  ACTION_PREPARE_APT_CLEANUP,
-};
-
-static int action_prepare (suite_config_action *action __attribute__ ((unused)), int data, di_packages *packages __attribute__ ((unused)), di_packages_allocator *allocator __attribute__ ((unused)), di_slist *install __attribute__ ((unused)))
-{
-  switch (data)
-  {
-    case ACTION_PREPARE_APT_PREPARE:
-      return install_apt_prepare ();
-    case ACTION_PREPARE_APT_CLEANUP:
-      return install_apt_cleanup ();
-  };
-  return 0;
+  return install_mount (action->what);
 }
 
 static struct suite_install_actions
@@ -194,18 +146,14 @@ static struct suite_install_actions
 }
 suite_install_actions[] =
 {
-  { "apt-cleanup", action_prepare, ACTION_PREPARE_APT_CLEANUP },
   { "apt-install", action_install, ACTION_INSTALL_APT_INSTALL },
-  { "apt-prepare", action_prepare, ACTION_PREPARE_APT_PREPARE },
   { "dpkg-configure", action_install, ACTION_INSTALL_DPKG_CONFIGURE },
   { "dpkg-install", action_install, ACTION_INSTALL_DPKG_INSTALL },
   { "dpkg-unpack", action_install, ACTION_INSTALL_DPKG_UNPACK },
-  { "dev-mount", action_mount, ACTION_MOUNT_DEV },
-  { "execute", action_execute, 0 },
   { "extract", action_install, ACTION_INSTALL_EXTRACT },
-  { "helper-install", action_helper, ACTION_HELPER_INSTALL },
-  { "helper-remove", action_helper, ACTION_HELPER_REMOVE },
-  { "proc-mount", action_mount, ACTION_MOUNT_PROC },
+  { "helper-install", action_helper_install, 0 },
+  { "helper-remove", action_helper_remove, 0 },
+  { "mount", action_mount, 0 },
   { NULL, NULL, 0 },
 };
 
@@ -232,7 +180,7 @@ int suite_action (di_packages *packages, di_packages_allocator *allocator, di_sl
         return 1;
     }
     else
-      log_text (DI_LOG_LEVEL_WARNING, "unknown action: %s", e->action);
+      log_text (DI_LOG_LEVEL_WARNING, "Unknown action: %s", e->action);
   }
 
   return 0;
